# Python API for controlling Hysen thermostats

The following devices are supported:
 - Hysen Heating Thermostat Controller Interface - device type 0x4EAD
 - Hysen Controller for 2 Pipe Fan Coil Interface - device type 0x4F5B
